import React from 'react'
import { Mutation } from 'react-apollo'
import {
  CREATE_NOTE,
  UPDATE_NOTE,
  GET_MANUSCRIPT,
  UPDATE_MANUSCRIPT,
} from './operations'

export const ManuscriptMutations = BaseComponent => ({
  manuscript,
  children,
  refetch = null,
  ...props
}) => (
  <Mutation
    mutation={UPDATE_MANUSCRIPT}
    refetchQueries={() => [
      {
        query: refetch || GET_MANUSCRIPT,
        variables: { id: manuscript.id },
      },
    ]}
  >
    {(updateManuscript, { data }) => {
      const { id } = manuscript
      const changeCitation = async citationData => {
        await updateManuscript({
          variables: { data: { id, ...citationData } },
        })
      }
      const updateEmbargo = async releaseDelay => {
        await updateManuscript({
          variables: { data: { id, meta: { releaseDelay } } },
        })
      }
      const updateGrants = async fundingGroup => {
        await updateManuscript({
          variables: { data: { id, meta: { fundingGroup } } },
        })
      }
      const setStatus = async (status, callBack) => {
        await updateManuscript({
          variables: { data: { id, status } },
        })
        callBack && callBack()
      }
      return (
        <BaseComponent
          changeCitation={changeCitation}
          manuscript={manuscript}
          setStatus={setStatus}
          updateEmbargo={updateEmbargo}
          updateGrants={updateGrants}
          {...props}
        >
          {children}
        </BaseComponent>
      )
    }}
  </Mutation>
)

export const NoteMutations = BaseComponent => ({
  manuscriptId,
  children,
  ...props
}) => (
  <Mutation mutation={UPDATE_NOTE}>
    {(updateNote, { data }) => {
      const changeNote = async note => {
        await updateNote({
          variables: {
            data: {
              ...note,
            },
          },
        })
      }
      return (
        <Mutation mutation={CREATE_NOTE}>
          {(createNote, { data }) => {
            const newNote = async note => {
              await createNote({
                variables: {
                  data: {
                    manuscriptId,
                    ...note,
                  },
                },
              })
            }
            return (
              <BaseComponent
                changeNote={changeNote}
                newNote={newNote}
                {...props}
              >
                {children}
              </BaseComponent>
            )
          }}
        </Mutation>
      )
    }}
  </Mutation>
)
