import React from 'react'
import ReactDOM from 'react-dom'
import { th } from '@pubsweet/ui-toolkit'
import styled, { createGlobalStyle } from 'styled-components'

const Limit = createGlobalStyle`
  #root > div > div {
    overflow: hidden;
  }
`
const Screen = styled.div`
  position: fixed;
  right: 0;
  left: 0;
  top: 0;
  bottom: 0;
  width: 100%;
  height: 100%;
  background-color: ${props =>
    props.transparent ? 'rgba(255, 255, 255, 0.6)' : th('colorTextReverse')};
  z-index: 3;
  display: flex;
  justify-content: center;
  align-items: center;
`
const Scroll = styled.div`
  margin: auto;
  width: 100%;
  max-height: 100%;
  overflow: auto;
`
export const Modal = styled.div`
  box-shadow: 0 0 8px ${th('colorBorder')};
  background-color: ${props =>
    props.accent ? th('colorBackgroundHue') : th('colorTextReverse')};
  border: ${th('borderWidth')} ${th('borderStyle')} ${th('colorBorder')};
  padding: calc(${th('gridUnit')} * 6);
  width: 800px;
  max-width: 85%;
  box-sizing: border-box;
  margin: calc(${th('gridUnit')} * 4) auto;
  & > p:first-child {
    margin: 0;
    & + h2 {
      margin-top: 0;
    }
  }
  h2:first-child {
    margin-top: 0;
  }
`
export const Cover = ({ children, ...props }) => (
  <Screen {...props}>
    <Limit />
    <Scroll>{children}</Scroll>
  </Screen>
)

export const Portal = ({ children, transparent, ...props }) =>
  ReactDOM.createPortal(
    <Cover transparent={transparent}>
      <Modal {...props}>{children}</Modal>
    </Cover>,
    document.getElementById('root').firstChild,
  )
