const config = require('config')
const rfr = require('rfr')

const minioClient = rfr('server/modules/pubsweet-component-minio')

const minioMiddleware = minioClient.middleware()
const download_path = config.file.url.download

module.exports = app => {
  app.post(
    '/api/upload',
    minioMiddleware({ op: minioClient.Ops.post }),
    (req, res) => {
      if (req.minio.error) {
        res.status(400).json({ error: req.minio.error })
      } else {
        res.send(`${download_path}/${req.minio.post.filename}`)
      }
    },
  )

  app.get(
    '/api/files',
    minioMiddleware({ op: minioClient.Ops.list }),
    (req, res) => {
      if (req.minio.error) {
        res.status(400).json({ error: req.minio.error })
      } else {
        res.send(req.minio.list)
      }
    },
  )

  app.get(
    `/api/files/:filename`,
    minioMiddleware({ op: minioClient.Ops.get }),
    (req, res) => {
      if (req.minio.error) {
        res.status(400).json({ error: req.minio.error })
        return
      }

      res.sendFile(req.minio.get.path, {}, err => {
        if (err) {
          res.status(500).json({ err })
        }
        minioClient.utils.removeFile(req.minio.get.path)
      })
    },
  )

  app.delete(
    '/api/files/:filename',
    minioMiddleware({ op: minioClient.Ops.delete }),
    (req, res) => {
      if (req.minio.error) {
        res.status(400).json({ error: req.minio.error })
      } else {
        res.send(req.minio.delete)
      }
    },
  )

  /* todo: make sure there is always a public method like this for NCBI to download the necessary
   * files for the pdf conversion stage. */
  app.get(
    `${download_path}/:filename`,
    minioMiddleware({ op: minioClient.Ops.get }),
    (req, res) => {
      if (req.minio.error) {
        res.status(400).json({ error: req.minio.error })
        return
      }

      res.download(req.minio.get.path, req.minio.get.originalName, err => {
        if (err) {
          console.warn('Download failed: ', err)
        }
        minioClient.utils.removeFile(req.minio.get.path)
      })
    },
  )
}
