const Manuscript = require('../manuscript/data-access')
const User = require('../user/data-access')
const Review = require('../review/data-access')
const Annotation = require('../annotation/data-access')
const Organization = require('../organization/data-access')
const Journal = require('../journal/data-access')
const Team = require('../team/data-access')

// const uuidv4 = require('uuid/v4')

const seed = async () => {
  const dummyUser = {
    type: 'user',
    admin: true,
    email: 'admin@example.com',
    teams: [],
    username: 'admin',
    fragments: [],
    collections: [],
    passwordHash:
      '$2b$12$afw/QukiWHP.aFN0ciL2weAhWo98Yj/PnZkyFxk/J72FkPFAerD5K',
  }
  const user = await new User().save(dummyUser)
  const orgId = await Organization.insert({ name: 'o1' })
  const journalId = await Journal.insert({ journalTitle: 'j1' })
  const dummyManuscript = {
    journalId,
    organizationId: orgId,
    createdBy: 'me',
    'meta,title': 'Some title',
    status: 'xml-qa',
    files: [],
  }
  const manuscript = await new Manuscript(dummyManuscript).save()
  // console.log(manuscript)

  const dummyReview = {
    manuscriptId: manuscript.id,
    userId: '70f46ae0-e1e4-43c1-9239-74bb76ebfc32',
    open: true,
    recommendation: 'this is my rec',
  }
  const review = await new Review(dummyReview).save()
  // console.log(review)

  const dummyAnnotation = {
    reviewId: review.id,
    userId: user.id,
    text: 'hiiiiiii',
    ranges: { attr: 'val' },
  }
  const annotation = await new Annotation(dummyAnnotation).save()
  // console.log(annotation)
  // const dummyTeam = {
  //   role: 'reviewer',
  //   objectId: '424d5c13-e0f0-44a5-94ec-d97038f97829',
  //   objectType: 'test type',
  // }
  // const team = await new Team(dummyTeam).save()
  // console.log(team)

  const dummyTeam = {
    roleName: 'reviewer',
    userId: '70f46ae0-e1e4-43c1-9239-74bb76ebfc32',
    manuscriptId: null,
  }
  const team = await new Team(dummyTeam).save()
  // console.log(team)
  return {
    manuscript,
    annotation,
    team,
  }
}

seed()
